import * as sanitizeHtml from 'sanitize-html';
import * as express from 'express';
/**
 * Sanitize any json schema.
 * By walk on all json tree and cleaning an existing string.
 * @param jsonSchema Json to sanitize.
 * @param cleanOptions 'sanitize-html' lib options.
 */
export declare function sanitizeJsonSync(jsonSchema: any, cleanOptions?: sanitizeHtml.IOptions | undefined): void;
/**
 * Sanitize any json schema async.
 * By walk on all json tree and cleaning an existing string.
 * @param jsonSchema Json to sanitize.
 * @param cleanOptions 'sanitize-html' lib options.
 * @returns the sanitized json object.
 */
export declare function sanitizeJsonAsync(jsonSchema: Object, cleanOptions?: sanitizeHtml.IOptions | undefined): Promise<Object>;
/**
 * Sanitize any request.body schema.
 * @param request express request.
 * @param response express response.
 * @param next express next.
 * @param cleanOptions optional 'sanitize-html' lib options, if undefined using default.
 */
export declare function sanitizeExpressMiddleware(request: express.Request, response: express.Response, next: express.NextFunction, cleanOptions?: sanitizeHtml.IOptions | undefined): void;
/**
 * Sanitize any request.body schema async.
 * @param request express request.
 * @param response express response.
 * @param next express next.
 * @param cleanOptions optional 'sanitize-html' lib options, if undefined using default.
 */
export declare function sanitizeExpressMiddlewareAsync(request: express.Request, response: express.Response, next: express.NextFunction, cleanOptions?: sanitizeHtml.IOptions | undefined): Promise<void>;
//# sourceMappingURL=index.d.ts.map