"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sanitizeJson = void 0;
const worker_threads_1 = require("worker_threads");
const sanitizeHtml = require("sanitize-html");
/**
 * Objects in js/json are a tree of values, so the easy way to run on all tree is to run it in recursive.
 * @param jsonSchema Json data to sanitize.
 * @param cleanOptions 'sanitize-html' options, for cleaning any string.
 */
function recursiveJsonSchemaCleaner(jsonSchema, cleanOptions = undefined) {
    /** If json is not an object, return. */
    if (!jsonSchema || typeof jsonSchema !== 'object') {
        return;
    }
    /**
     * Iterate on each object / array value. (array is implementation of object.).
     * And if value is a string, clean it. that's all.
     */
    for (const [key, value] of Object.entries(jsonSchema)) {
        if (typeof value !== 'string') {
            recursiveJsonSchemaCleaner(value, cleanOptions);
        }
        else {
            jsonSchema[key] = sanitizeHtml(value, cleanOptions);
        }
    }
}
/**
 * Sanitize any json schema.
 * By walk on all json tree and cleaning an existing string.
 * @param jsonSchema Json to sanitize.
 * @param cleanOptions 'sanitize-html' lib options.
  */
function sanitizeJson(jsonSchema, cleanOptions = undefined) {
    recursiveJsonSchemaCleaner(jsonSchema, cleanOptions);
}
exports.sanitizeJson = sanitizeJson;
/** If using module as 'worker_threads' alloc json from 'workerData' and do work. */
if (worker_threads_1.workerData)
    sanitizeJson(worker_threads_1.workerData.jsonSchema, worker_threads_1.workerData.cleanOptions);
/** If there is a parent port, give it the result. */
if (worker_threads_1.parentPort)
    worker_threads_1.parentPort.postMessage(worker_threads_1.workerData.jsonSchema);
//# sourceMappingURL=sanitizer.js.map